@@ -1,6 +1,6 @@
 package Bundle::ePortal;
 
-$VERSION = 0.04;
+$VERSION = 0.07;
 
 1;
 
@@ -49,8 +49,6 @@ Mail::Sendmail
 
 MIME::Base64
 
-MD5
-
 Net::LDAP
 
 Params::Validate
@@ -63,10 +61,17 @@ Unicode::Map8
 
 Unicode::String
 
+URI
 
+ePortal::Server
 
+ePortal::App::OffPhones
 
+ePortal::App::MsgForum
 
+ePortal::App::Organizer
+
+ePortal::App::Diskoteka
 
 
 =head1 DESCRIPTION
